import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import {
  AllEcogestureData,
  defaultEcogestureData,
} from '../../../tests/__mocks__/actionData.mock'
import { mockedEcogesturesData } from '../../../tests/__mocks__/ecogesturesData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { profileData } from '../../../tests/__mocks__/profileData.mock'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import ActionBegin from './ActionBegin'
import ActionModal from './ActionModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockgetCustomActions = jest.fn()
const mockgetDefaultActions = jest.fn()

jest.mock('services/action.service', () => {
  return jest.fn(() => {
    return {
      getCustomActions: mockgetCustomActions,
      getDefaultActions: mockgetDefaultActions,
    }
  })
})
const mockImportIconById = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconById: jest.fn(() => {
      return mockImportIconById
    }),
  }
})
const mockStore = configureStore([])

describe('ActionBegin component', () => {
  it('should render correctly', async () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    mockImportIconById.mockReturnValue('')

    const wrapper = mount(
      <Provider store={store}>
        <ActionBegin
          action={defaultEcogestureData[1]}
          setShowList={jest.fn()}
          userChallenge={userChallengeData[1]}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should render correctly with custom action', async () => {
    mockgetCustomActions.mockResolvedValue([
      AllEcogestureData[0],
      AllEcogestureData[5],
      AllEcogestureData[2],
    ])
    mockImportIconById.mockReturnValue('')
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: { ...profileData, isProfileTypeCompleted: true },
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionBegin
          action={mockedEcogesturesData[1]}
          setShowList={jest.fn()}
          userChallenge={userChallengeData[1]}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.action-title').text()).toBe('Coup de vent')
  })
  it('should render chosen action ', async () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    mockImportIconById.mockReturnValue('')

    const wrapper = mount(
      <Provider store={store}>
        <ActionBegin
          action={defaultEcogestureData[1]}
          setShowList={jest.fn()}
          userChallenge={userChallengeData[1]}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find(ActionBegin).exists()).toBeTruthy()
  })
  it('should open launch Modal ', async () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    mockImportIconById.mockReturnValue('')

    const wrapper = mount(
      <Provider store={store}>
        <ActionBegin
          action={defaultEcogestureData[1]}
          setShowList={jest.fn()}
          userChallenge={userChallengeData[1]}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).first().simulate('click')
    expect(wrapper.find(ActionModal).exists()).toBeTruthy()
    expect(wrapper.find(ActionModal).prop('open')).toBeTruthy()
  })
  it('should go to the list ', async () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    mockImportIconById.mockReturnValue('')

    const wrapper = mount(
      <Provider store={store}>
        <ActionBegin
          action={defaultEcogestureData[1]}
          setShowList={jest.fn()}
          userChallenge={userChallengeData[1]}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).at(1).simulate('click')
  })
})
