import { Button } from '@material-ui/core'
import EcogestureModal from 'components/Ecogesture/EcogestureModal'
import { UserActionState } from 'enum/userAction.enum'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import { DateTime } from 'luxon'
import { UserAction } from 'models'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { defaultEcogestureData } from '../../../tests/__mocks__/actionData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { profileData } from '../../../tests/__mocks__/profileData.mock'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import ActionOnGoing from './ActionOnGoing'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockImportIconById = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconById: jest.fn(() => {
      return mockImportIconById
    }),
  }
})
const mockStore = configureStore([])

describe('ActionOnGoing component', () => {
  const userAction: UserAction = {
    ecogesture: null,
    startDate: DateTime.local(2020, 1, 1)
      .setZone('utc', {
        keepLocalTime: true,
      })
      .startOf('day'),
    state: UserActionState.ONGOING,
  }
  it('should render correctly', async () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })

    const wrapper = mount(
      <Provider store={store}>
        <ActionOnGoing userAction={userAction} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should click on button open ecogesture Modal', async () => {
    const userAction1: UserAction = {
      ecogesture: defaultEcogestureData[1],
      startDate: null,
      state: UserActionState.ONGOING,
    }
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionOnGoing userAction={userAction1} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).first().simulate('click')
    expect(wrapper.find(EcogestureModal).exists()).toBeTruthy()
  })
})
