import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import React from 'react'
import { useNavigate } from 'react-router-dom'
import './analysisError.scss'

const AnalysisErrorModal = () => {
  const { t } = useI18n()
  const navigate = useNavigate()
  const goToConsumption = () => {
    navigate('/consumption')
  }
  const goBack = () => {
    if (history.length <= 2) {
      navigate('/consumption')
    } else navigate(-1)
  }
  return (
    <Dialog
      open={true}
      onClose={(event, reason): void => {
        event && reason !== 'backdropClick' && goBack()
      }}
      disableEscapeKeyDown
      aria-labelledby={'accessibility-title'}
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id={'accessibility-title'}>
        {t('analysis_error_modal.accessibility.window_title')}
      </div>
      <div className="em-root analysis-error-container">
        <div className="em-content">
          <div className="analysis-error-title text-20-bold">
            {t('analysis_error_modal.title')}
          </div>
          <div className="analysis-error-message text-16-normal">
            {t('analysis_error_modal.message')}
          </div>
          <div className="analysis-error-button">
            <Button
              aria-label={t(
                'analysis_error_modal.accessibility.button_go_back'
              )}
              onClick={goBack}
              classes={{
                root: 'btn-secondary-positive',
                label: 'text-16-normal',
              }}
            >
              {t('analysis_error_modal.go_back')}
            </Button>
            <Button
              aria-label={t(
                'analysis_error_modal.accessibility.button_goto_konnector'
              )}
              onClick={goToConsumption}
              classes={{
                root: 'btn-highlight',
                label: 'text-16-bold',
              }}
            >
              {t('analysis_error_modal.go_to_options')}
            </Button>
          </div>
        </div>
      </div>
    </Dialog>
  )
}

export default AnalysisErrorModal
