import { DataloadState } from 'enum/dataload.enum'
import { FluidType } from 'enum/fluid.enum'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import { DateTime } from 'luxon'
import { Datachart } from 'models'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { graphMonthData } from '../../../tests/__mocks__/chartData.mock'
import { mockAnalysisState } from '../../../tests/__mocks__/store'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import TotalAnalysisChart from './TotalAnalysisChart'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockgetGraphData = jest.fn()
jest.mock('services/consumption.service', () => {
  return jest.fn(() => {
    return {
      getGraphData: mockgetGraphData,
    }
  })
})
jest.mock('components/Analysis/PieChart', () => 'mock-piechart')

const mockStore = configureStore([])
const store = mockStore({
  ecolyo: {
    analysis: mockAnalysisState,
  },
})
describe('TotalAnalysisChart component', () => {
  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <TotalAnalysisChart fluidTypes={[FluidType.ELECTRICITY]} />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should render several fluids and display month data', async () => {
    mockgetGraphData.mockResolvedValueOnce(graphMonthData)
    const wrapper = mount(
      <Provider store={store}>
        <TotalAnalysisChart
          fluidTypes={[FluidType.ELECTRICITY, FluidType.WATER, FluidType.GAS]}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.fluidconso').exists()).toBeTruthy()
  })
  it('should render empty price', async () => {
    const emptyData: Datachart = {
      actualData: [
        {
          date: DateTime.fromISO('2020-09-01T00:00:00.000Z', {
            zone: 'utc',
          }),
          value: 69.18029999999999,
          state: DataloadState.VALID,
          valueDetail: [{ value: -1, state: DataloadState.EMPTY }],
        },
      ],
      comparisonData: null,
    }
    mockgetGraphData.mockResolvedValueOnce(emptyData)
    const wrapper = mount(
      <Provider store={store}>
        <TotalAnalysisChart
          fluidTypes={[FluidType.ELECTRICITY, FluidType.WATER]}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.fluidconso').text()).toBe('--- €')
  })
  it('should render empty price for one fluid', async () => {
    const emptyData: Datachart = {
      actualData: [
        {
          date: DateTime.fromISO('2020-09-01T00:00:00.000Z', {
            zone: 'utc',
          }),
          value: 69.18029999999999,
          state: DataloadState.VALID,
          valueDetail: [{ value: -1, state: DataloadState.EMPTY }],
        },
      ],
      comparisonData: null,
    }
    mockgetGraphData.mockResolvedValueOnce(emptyData)
    const wrapper = mount(
      <Provider store={store}>
        <TotalAnalysisChart fluidTypes={[FluidType.ELECTRICITY]} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.fluidconso').exists()).toBe(false)
  })
})
