import { DataloadSectionType } from 'enum/dataload.enum'
import { FluidType } from 'enum/fluid.enum'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import { Dataload } from 'models'
import React from 'react'
import { baseDataLoad } from '../../../tests/__mocks__/chartData.mock'
import DataloadSection from './DataloadSection'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

jest.mock(
  'components/ConsumptionVisualizer/DataloadSectionValue',
  () => 'mock-dataloadsectionvalue'
)
jest.mock(
  'components/ConsumptionVisualizer/DataloadSectionDetail',
  () => 'mock-dataloadsectiondetail'
)

const mockToggleEstimationModal = jest.fn()

describe('DataloadSection component', () => {
  const mockDataload: Dataload = baseDataLoad

  it('should render correctly', () => {
    const wrapper = mount(
      <DataloadSection
        dataload={mockDataload}
        fluidType={FluidType.ELECTRICITY}
        dataloadSectionType={DataloadSectionType.NO_COMPARE}
        toggleEstimationModal={mockToggleEstimationModal}
      />
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should render no_data when dataload value is -1 and section is left', () => {
    const _mockDatalaod = { ...mockDataload, value: -1 }
    const wrapper = mount(
      <DataloadSection
        dataload={_mockDatalaod}
        fluidType={FluidType.ELECTRICITY}
        dataloadSectionType={DataloadSectionType.LEFT}
        toggleEstimationModal={mockToggleEstimationModal}
      />
    )
    expect(wrapper.find('.dataloadvisualizer-novalue').text()).toBe(
      'consumption_visualizer.no_data'
    )
  })
})
