import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { profileData } from '../../../tests/__mocks__/profileData.mock'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import DuelResultModal from './DuelResultModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockImportIconById = jest.fn()
const mockFormatNumberValues = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconById: jest.fn(() => {
      return mockImportIconById
    }),
    formatNumberValues: jest.fn(() => {
      return mockFormatNumberValues
    }),
  }
})
const mockStore = configureStore([])

describe('DuelResultModal component', () => {
  it('should render correctly', async () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    mockImportIconById.mockReturnValue('')
    const wrapper = mount(
      <Provider store={store}>
        <DuelResultModal
          open={true}
          handleCloseClick={jest.fn()}
          userChallenge={userChallengeData[1]}
          win={true}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should render a loss modal', async () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    mockImportIconById.mockReturnValue('')

    const wrapper = mount(
      <Provider store={store}>
        <DuelResultModal
          open={true}
          handleCloseClick={jest.fn()}
          userChallenge={userChallengeData[1]}
          win={false}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.title').text()).toBe('duel_result_modal.lost.title')
  })
})
