import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import challengeWon from 'assets/icons/visu/duelResult/challengeWon.svg'
import defaultIcon from 'assets/icons/visu/duelResult/default.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import { UserChallenge } from 'models/challenge.model'
import React, { useEffect, useState } from 'react'
import { formatNumberValues, importIconById } from 'utils/utils'
import './duelResultModal.scss'

interface DuelResultModalProps {
  open: boolean
  userChallenge: UserChallenge
  win: boolean
  handleCloseClick: () => void
}

const DuelResultModal = ({
  open,
  userChallenge,
  win,
  handleCloseClick,
}: DuelResultModalProps) => {
  const { t } = useI18n()
  const [winIcon, setWinIcon] = useState<string>(defaultIcon)
  const [lossIcon, setLossIcon] = useState<string>(defaultIcon)
  const result: string | number = formatNumberValues(
    Math.abs(userChallenge.duel.threshold - userChallenge.duel.userConsumption)
  )

  useEffect(() => {
    async function handleEcogestureIcon() {
      const icon = await importIconById(userChallenge.id + '-1', 'duelResult')
      if (icon) {
        setWinIcon(icon)
      } else {
        setWinIcon(defaultIcon)
      }
      const icon2 = await importIconById(userChallenge.id + '-0', 'duelResult')
      if (icon2) {
        setLossIcon(icon2)
      } else {
        setLossIcon(defaultIcon)
      }
    }
    handleEcogestureIcon()
  }, [userChallenge])

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby={'accessibility-title'}
      classes={{
        root: 'modal-root',
        paper: 'modal-paper blue-border',
      }}
    >
      <div id={'accessibility-title'}>
        {t('duel_result_modal.accessibility.window_title')}
      </div>
      <div className="duel-result-modal-root ">
        <div className="imgResultContainer">
          {win && (
            <Icon className="challengeWon" icon={challengeWon} size={300} />
          )}
          <Icon
            className="imgResult"
            icon={win ? winIcon : lossIcon}
            size={180}
          />
        </div>
        <div className="text-28-normal-uppercase title">
          {win
            ? t('duel_result_modal.sucess.title')
            : t('duel_result_modal.lost.title')}
        </div>
        <div className="text-18-normal">
          {win
            ? t('duel_result_modal.sucess.message1') + result + ' €'
            : t('duel_result_modal.lost.message1') + result + ' €'}
        </div>
        <div className="text-18-normal">
          {win
            ? t('duel_result_modal.sucess.message2') + userChallenge.title
            : t('duel_result_modal.lost.message2') +
              userChallenge.title +
              '...'}
        </div>
        <Button
          aria-label={t('duel_result_modal.accessibility.button_validate')}
          className="button"
          onClick={handleCloseClick}
          classes={{
            root: 'btn-secondary-negative',
            label: 'text-16-normal',
          }}
        >
          {win
            ? t('duel_result_modal.sucess.button_validate')
            : t('duel_result_modal.lost.button_validate')}
        </Button>
      </div>
    </Dialog>
  )
}

export default DuelResultModal
