import ExplorationOngoing from 'components/Exploration/ExplorationOngoing'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockUserChallengeUpdateFlag = jest.fn()
const mockIsChallengeDone = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => {
    return {
      updateUserChallenge: mockUserChallengeUpdateFlag,
      isChallengeDone: mockIsChallengeDone,
    }
  })
})

const mockHistoryPush = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => ({
    push: mockHistoryPush,
  }),
}))

const mockStore = configureStore([])

describe('ExplorationOngoing component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ExplorationOngoing userChallenge={userChallengeData[0]} />
      </Provider>
    )
    expect(
      wrapper.find('.exploration-explanation > div').first().text()
    ).toEqual(userChallengeData[1].exploration.description)
    expect(
      wrapper.find('.exploration-explanation > div').last().text()
    ).toEqual(userChallengeData[1].exploration.complementary_description)
    expect(wrapper.find('.button-start').exists()).toBeTruthy()
  })
})
