import TotalConsumption from 'components/TotalConsumption/TotalConsumption'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { FluidType } from 'enum/fluid.enum'
import { TimeStep } from 'enum/timeStep.enum'
import React from 'react'
import { useSelector } from 'react-redux'
import { AppStore } from 'store'
import { convertDateToShortDateString } from 'utils/date'
import './consumptionDetails.scss'

const ConsumptionDetails = ({ fluidType }: { fluidType: FluidType }) => {
  const { t } = useI18n()
  const { currentTimeStep, currentDatachart, showCompare } = useSelector(
    (state: AppStore) => state.ecolyo.chart
  )

  return (
    <>
      <div className="consumption-details-root">
        <div className="consumption-details-content">
          <div className="consumption-details-header text-16-normal-uppercase details-title">
            {convertDateToShortDateString(
              currentDatachart.actualData,
              currentTimeStep
            )}
            {showCompare && (
              <div className="consumption-details-header compare">
                {t('consumption.compared')}
                {currentTimeStep === TimeStep.DAY && ' '}
                {currentTimeStep !== TimeStep.DAY && ' AU '}
                {convertDateToShortDateString(
                  currentDatachart.comparisonData,
                  currentTimeStep
                )}
              </div>
            )}
          </div>
          <TotalConsumption fluidType={fluidType} />
        </div>
      </div>
    </>
  )
}

export default ConsumptionDetails
