import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import * as reactRedux from 'react-redux'
import { Provider } from 'react-redux'
import {
  createMockEcolyoStore,
  mockInitialGlobalState,
} from '../../../tests/__mocks__/store'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import KonnectorViewerList from './KonnectorViewerList'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

describe('KonnectorViewerList component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    store.clearActions()
  })

  it('should be rendered correctly', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <KonnectorViewerList />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should click on card and nav to fluid', async () => {
    const mockUseSelector = jest.spyOn(reactRedux, 'useSelector')

    mockUseSelector.mockReturnValue({
      fluidStatus: mockInitialGlobalState.fluidStatus,
    })
    const wrapper = mount(
      <Provider store={store}>
        <KonnectorViewerList />
      </Provider>
    )
    wrapper.find('.connection-card').first().simulate('click')
    expect(mockedNavigate).toHaveBeenCalled()
  })
})
