import Link from '@material-ui/core/Link'
import LegalNoticeIcon from 'assets/icons/ico/legal-notice.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { UsageEventType } from 'enum/usageEvent.enum'
import React, { useCallback } from 'react'
import { Link as RouterLink } from 'react-router-dom'
import UsageEventService from 'services/usageEvent.service'
import './legalNoticeLink.scss'

const LegalNoticeLink = () => {
  const { t } = useI18n()
  const client = useClient()
  const emitNavEvent = useCallback(async () => {
    await UsageEventService.addEvent(client, {
      type: UsageEventType.NAVIGATION_EVENT,
      target: 'legalNotice',
    })
  }, [client])
  return (
    <div className="legal-notice-root">
      <div className="legal-notice-content">
        <div className="legal-notice-header text-16-normal-uppercase">
          {t('legal.title_legal')}
        </div>
        <Link
          className="legal-notice-card-link"
          component={RouterLink}
          to="/options/legalnotice"
        >
          <div className="card optionCard" onClick={emitNavEvent}>
            <div className="legal-notice-card">
              <div className="legal-notice-card-content">
                <StyledIcon
                  className="legal-notice-card-content-icon"
                  icon={LegalNoticeIcon}
                  size={42}
                />
                <div className="legal-notice-card-content-title">
                  {t('legal.read_legal')}
                </div>
              </div>
            </div>
          </div>
        </Link>
      </div>
    </div>
  )
}

export default LegalNoticeLink
