import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import UsageEventService from 'services/usageEvent.service'
import { mockProfileType } from '../../../tests/__mocks__/profileType.mock'
import { createMockEcolyoStore } from '../../../tests/__mocks__/store'
import ProfileTypeFinished from './ProfileTypeFinished'

const mockedNavigate = jest.fn()

jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useLocation: () => ({
    pathname: '/ecogesture-form',
  }),
  useNavigate: () => mockedNavigate,
}))
jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockAddEvent = jest.fn()
jest.mock('services/usageEvent.service')
UsageEventService.addEvent = mockAddEvent

const mockGetAllProfileTypes = jest.fn()
const mockDeleteProfileTypes = jest.fn()
jest.mock('services/profileTypeEntity.service', () => {
  return jest.fn(() => {
    return {
      getAllProfileTypes: mockGetAllProfileTypes,
      deleteProfileTypes: mockDeleteProfileTypes,
    }
  })
})

describe('ProfileTypeFinished component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    store.clearActions()
    jest.clearAllMocks()
  })

  it('should be rendered correctly', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeFinished profileType={mockProfileType} />
      </Provider>
    )
    expect(wrapper.find('profile-type-finished-card')).toBeTruthy()
  })
  it('should go to ecogesture selection', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeFinished profileType={mockProfileType} />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(mockedNavigate).toHaveBeenCalledWith('/ecogesture-selection')
  })
})
