import FormNavigation from 'components/FormGlobal/FormNavigation'
import FormProgress from 'components/FormGlobal/FormProgress'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { ProfileTypeStepForm } from 'enum/profileType.enum'
import {
  ProfileType,
  ProfileTypeAnswer,
  ProfileTypeValues,
} from 'models/profileType.model'
import React, { useCallback, useEffect, useState } from 'react'
import { useSelector } from 'react-redux'
import { AppStore } from 'store'

interface ProfileTypeFormNumberProps {
  step: ProfileTypeStepForm
  viewedStep: ProfileTypeStepForm
  currentProfileType: ProfileType
  answerType: ProfileTypeAnswer
  setNextStep: (_profileType: ProfileType) => void
  setPreviousStep: () => void
}

const ProfileTypeFormNumber = ({
  step,
  viewedStep,
  currentProfileType,
  answerType,
  setNextStep,
  setPreviousStep,
}: ProfileTypeFormNumberProps) => {
  const { t } = useI18n()
  const { isProfileTypeCompleted } = useSelector(
    (state: AppStore) => state.ecolyo.profile
  )
  const [answer, setAnswer] = useState<ProfileTypeValues>('')

  const handlePrevious = useCallback(() => {
    setPreviousStep()
  }, [setPreviousStep])

  const handleNext = useCallback(() => {
    setNextStep({ ...currentProfileType, [answerType.attribute]: answer })
  }, [currentProfileType, setNextStep, answer, answerType.attribute])

  useEffect(() => {
    if (step < viewedStep || isProfileTypeCompleted) {
      setAnswer(currentProfileType[answerType.attribute])
    }
  }, [step, viewedStep, currentProfileType, answerType, isProfileTypeCompleted])

  return (
    <>
      <div className={'profile-form-container'}>
        <FormProgress step={step} formType={'profile'} />
        <div className={'profile-question-label'}>
          {t(
            `profile_type.${ProfileTypeStepForm[step].toLowerCase()}.question`
          )}
        </div>
        {answer != null && (
          <label className={'text'}>
            <input
              type={'number'}
              value={answer.toString()}
              name={answerType.attribute}
              onChange={e => setAnswer(e.target.value)}
              autoFocus
            />
            m²
          </label>
        )}
      </div>
      <FormNavigation
        step={step}
        handlePrevious={handlePrevious}
        handleNext={handleNext}
        disableNextButton={answer === ''}
      />
    </>
  )
}

export default ProfileTypeFormNumber
