import { QueryResult } from 'cozy-client'
import { Konnector } from 'models'
import { accountsData } from '../../tests/__mocks__/accountsData.mock'
import mockClient from '../../tests/__mocks__/client'
import { konnectorsData } from '../../tests/__mocks__/konnectorsData.mock'
import { triggersData } from '../../tests/__mocks__/triggersData.mock'
import { triggerStateData } from '../../tests/__mocks__/triggerStateData.mock'
import KonnectorService from './konnector.service'

const mockGetTrigger = jest.fn()
const mockFetchTriggerState = jest.fn()
jest.mock('./triggers.service', () => {
  return jest.fn(() => {
    return {
      getTrigger: mockGetTrigger,
      fetchTriggerState: mockFetchTriggerState,
    }
  })
})

describe('KonnectorService service', () => {
  const konnectorService = new KonnectorService(mockClient)

  describe('getKonnector method', () => {
    it('should return konnector', async () => {
      const mockQueryResult: QueryResult<Konnector[]> = {
        data: [konnectorsData[0]],
        bookmark: '',
        next: false,
        skip: 0,
      }
      mockClient.query.mockResolvedValueOnce(mockQueryResult)
      const result = await konnectorService.getKonnector('enedissgegrandlyon')
      expect(result).toEqual(konnectorsData[0])
    })

    it('should return null when konnector is not found', async () => {
      const mockQueryResult: QueryResult<Konnector[]> = {
        data: [],
        bookmark: '',
        next: false,
        skip: 0,
      }
      mockClient.query.mockResolvedValueOnce(mockQueryResult)
      const result = await konnectorService.getKonnector('enedissgegrandlyon')
      expect(result).toBeNull()
    })
  })

  describe('getKonnectorLastState method', () => {
    it('should return the triggerState', async () => {
      mockGetTrigger.mockResolvedValueOnce(triggersData[0])
      mockFetchTriggerState.mockResolvedValueOnce(triggerStateData)
      const result = await konnectorService.getKonnectorLastState(
        konnectorsData[0],
        accountsData[0]
      )
      expect(result).toEqual(triggerStateData)
    })

    it('should return null when trigger is not found', async () => {
      mockGetTrigger.mockResolvedValueOnce(null)
      mockFetchTriggerState.mockResolvedValueOnce(triggerStateData)
      const result = await konnectorService.getKonnectorLastState(
        konnectorsData[0],
        accountsData[0]
      )
      expect(result).toEqual(null)
    })
  })

  describe('createIndexKonnector method', () => {
    it('should return the query Result', async () => {
      const mockQueryResult: QueryResult<Konnector[]> = {
        data: [],
        bookmark: '',
        next: false,
        skip: 0,
      }
      mockClient.query.mockResolvedValueOnce(mockQueryResult)
      const result = await konnectorService.createIndexKonnector()
      expect(result).toEqual([])
    })
  })
})
