import { PayloadAction, createSlice } from '@reduxjs/toolkit'
import { DateTime } from 'luxon'
import { AnalysisState } from 'models'

const initialState: AnalysisState = {
  period: 'month',
  analysisMonth: DateTime.local().minus({ months: 1 }).startOf('day'),
}

type SetPeriodAction = PayloadAction<'month' | 'year'>
type SetSelectedMonthAction = PayloadAction<DateTime>

export type AnalysisActionTypes = SetPeriodAction | SetSelectedMonthAction

export const analysisSlice = createSlice({
  name: 'analysis',
  initialState,
  reducers: {
    setPeriod: (state, action: SetPeriodAction) => {
      state.period = action.payload
    },
    setAnalysisMonth: (state, action: SetSelectedMonthAction) => {
      state.analysisMonth = action.payload
    },
  },
})

export const { setPeriod, setAnalysisMonth } = analysisSlice.actions
