import { PayloadAction, createSlice } from '@reduxjs/toolkit'
import { UserChallengeState } from 'enum/userChallenge.enum'
import { ChallengeState, Dataload, UserChallenge } from 'models'

const initialState: ChallengeState = {
  userChallengeList: [],
  currentChallenge: null,
  currentDataload: [],
}

type SetUserChallengeList = PayloadAction<UserChallenge[]>
type UpdateUserChallengeList = PayloadAction<UserChallenge>
type UnlockNextUserChallenge = PayloadAction<UserChallenge>
type SetChallengeConsumption = PayloadAction<{
  userChallenge: UserChallenge
  currentDataload: Dataload[]
}>

export type ChallengeActionTypes =
  | SetUserChallengeList
  | UpdateUserChallengeList
  | UnlockNextUserChallenge
  | SetChallengeConsumption

export const challengeSlice = createSlice({
  name: 'challenge',
  initialState,
  reducers: {
    setUserChallengeList: (state, action: SetUserChallengeList) => {
      const filteredCurrentChallenge = action.payload.filter(
        challenge =>
          challenge.state === UserChallengeState.ONGOING ||
          challenge.state === UserChallengeState.DUEL
      )
      const currentChallenge = filteredCurrentChallenge[0] || null

      state.userChallengeList = action.payload
      state.currentChallenge = currentChallenge
    },
    updateUserChallengeList: (state, action: UpdateUserChallengeList) => {
      const id = action.payload.id
      const currentChallenge =
        action.payload.state === UserChallengeState.ONGOING ||
        action.payload.state === UserChallengeState.DUEL
          ? action.payload
          : null
      const updatedList = [...state.userChallengeList]
      const findIndex = updatedList.findIndex(challenge => challenge.id === id)
      updatedList[findIndex] = action.payload

      state.userChallengeList = updatedList
      state.currentChallenge = currentChallenge || state.currentChallenge
    },
    unlockNextUserChallenge: (state, action: UnlockNextUserChallenge) => {
      const id = action.payload.id
      const updatedList = [...state.userChallengeList]
      const findIndex = updatedList.findIndex(challenge => challenge.id === id)
      updatedList[findIndex] = action.payload
      if (typeof updatedList[findIndex + 1] !== 'undefined') {
        updatedList[findIndex + 1] = {
          ...updatedList[findIndex + 1],
          state: UserChallengeState.UNLOCKED,
        }
      }

      state.userChallengeList = updatedList
      state.currentChallenge = null
    },
    setChallengeConsumption: (state, action: SetChallengeConsumption) => {
      const id = action.payload.userChallenge.id
      const updatedList = [...state.userChallengeList]
      const findIndex = updatedList.findIndex(challenge => challenge.id === id)
      updatedList[findIndex] = action.payload.userChallenge

      state.userChallengeList = updatedList
      state.currentDataload = action.payload.currentDataload
      if (
        state.currentChallenge &&
        state.currentChallenge.id === action.payload.userChallenge.id
      ) {
        state.currentChallenge = action.payload.userChallenge
      }
    },
  },
})

export const {
  setChallengeConsumption,
  setUserChallengeList,
  unlockNextUserChallenge,
  updateUserChallengeList,
} = challengeSlice.actions
