import { ScreenType } from 'enum/screen.enum'
import { mockInitialGlobalState } from '../../../tests/__mocks__/store'
import {
  CHANGE_SCREEN_TYPE,
  GlobalActionTypes,
  SET_FLUID_STATUS,
  TOGGLE_ANALYSIS_NOTIFICATION,
  TOGGLE_CHALLENGE_ACTION_NOTIFICATION,
  TOGGLE_CHALLENGE_DUEL_NOTIFICATION,
  TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION,
  changeScreenType,
  setFluidStatus,
  toggleAnalysisNotification,
  toggleChallengeActionNotification,
  toggleChallengeDuelNotification,
  toggleChallengeExplorationNotification,
} from './global.actions'

describe('global actions', () => {
  it('should create an action to change screenType', () => {
    const screenType = ScreenType.DESKTOP
    const expectedAction: GlobalActionTypes = {
      type: CHANGE_SCREEN_TYPE,
      payload: screenType,
    }
    expect(changeScreenType(screenType)).toEqual(expectedAction)
  })

  it('should create an action to toggle challenge exploration notification', () => {
    const notification = true
    const expectedAction: GlobalActionTypes = {
      type: TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION,
      payload: notification,
    }
    expect(toggleChallengeExplorationNotification(notification)).toEqual(
      expectedAction
    )
  })

  it('should create an action to toggle challenge action notification', () => {
    const notification = true
    const expectedAction: GlobalActionTypes = {
      type: TOGGLE_CHALLENGE_ACTION_NOTIFICATION,
      payload: notification,
    }
    expect(toggleChallengeActionNotification(notification)).toEqual(
      expectedAction
    )
  })

  it('should create an action to toggle challenge duel notification', () => {
    const notification = true
    const expectedAction: GlobalActionTypes = {
      type: TOGGLE_CHALLENGE_DUEL_NOTIFICATION,
      payload: notification,
    }
    expect(toggleChallengeDuelNotification(notification)).toEqual(
      expectedAction
    )
  })

  it('should create an action to toggle analysis notification', () => {
    const notification = true
    const expectedAction: GlobalActionTypes = {
      type: TOGGLE_ANALYSIS_NOTIFICATION,
      payload: notification,
    }
    expect(toggleAnalysisNotification(notification)).toEqual(expectedAction)
  })

  it('should create an action to set fluid status', () => {
    const fluidStatus = mockInitialGlobalState.fluidStatus
    const expectedAction: GlobalActionTypes = {
      type: SET_FLUID_STATUS,
      payload: fluidStatus,
    }
    expect(setFluidStatus(fluidStatus)).toEqual(expectedAction)
  })
})
