import * as Sentry from '@sentry/react'
import { Client } from 'cozy-client'
import {
  AnalysisState,
  ChallengeState,
  GlobalState,
  ModalState,
  Profile,
  ProfileType,
} from 'models'
import { ChartState } from 'models/chart.model'
import { ProfileEcogesture } from 'models/profileEcogesture.model'
import {
  Store,
  applyMiddleware,
  combineReducers,
  compose,
  createStore,
} from 'redux'
import { composeWithDevTools } from 'redux-devtools-extension'
import thunkMiddleware from 'redux-thunk'
import { globalReducer } from 'store/global/global.reducer'
import { AnalysisActionTypes, analysisSlice } from './analysis/analysis.slice'
import {
  ChallengeActionTypes,
  challengeSlice,
} from './challenge/challenge.slice'
import { ChartActionTypes, chartSlice } from './chart/chart.slice'
import { GlobalActionTypes } from './global/global.actions'
import { ModalActionTypes, modalSlice } from './modal/modal.slice'
import { ProfileActionTypes } from './profile/profile.actions'
import { profileReducer } from './profile/profile.reducer'
import { ProfileEcogestureActionTypes } from './profileEcogesture/profileEcogesture.actions'
import { profileEcogestureReducer } from './profileEcogesture/profileEcogesture.reducer'
import {
  ProfileTypeActionTypes,
  profileTypeSlice,
} from './profileType/profileType.slice'

export interface EcolyoState {
  analysis: AnalysisState
  challenge: ChallengeState
  chart: ChartState
  global: GlobalState
  modal: ModalState
  profile: Profile
  profileEcogesture: ProfileEcogesture
  profileType: ProfileType
}

export const defaultAction = { type: null, payload: undefined }

const ecolyoReducer = combineReducers({
  analysis: analysisSlice.reducer,
  challenge: challengeSlice.reducer,
  chart: chartSlice.reducer,
  global: globalReducer,
  modal: modalSlice.reducer,
  profile: profileReducer,
  profileEcogesture: profileEcogestureReducer,
  profileType: profileTypeSlice.reducer,
})

export interface AppStore {
  ecolyo: EcolyoState
  cozy: unknown
}

const appActions = {
  ...analysisSlice.actions,
  ...challengeSlice.actions,
  ...chartSlice.actions,
  ...modalSlice.actions,
  ...profileTypeSlice.actions,
}

// TODO refactor types with AppActionsTypes = typeof appActions
export type AppActionsTypes =
  | AnalysisActionTypes
  | ChallengeActionTypes
  | ChartActionTypes
  | GlobalActionTypes
  | ModalActionTypes
  | ProfileActionTypes
  | ProfileEcogestureActionTypes
  | ProfileTypeActionTypes

const sentryReduxEnhancer = Sentry.createReduxEnhancer({})

const configureStore = (client: Client, persistedState: any) => {
  const middlewares = [thunkMiddleware.withExtraArgument({ client })]
  const composeEnhancers =
    composeWithDevTools({ trace: true, actionCreators: appActions }) || compose

  const store: Store<AppStore, AppActionsTypes> = createStore(
    combineReducers({
      ecolyo: ecolyoReducer,
      cozy: client.reducer(),
      persistedState,
    }),
    composeEnhancers(
      // eslint-disable-next-line prefer-spread
      applyMiddleware.apply(null, middlewares),
      sentryReduxEnhancer
    )
  )
  return store
}
export default configureStore
